==> libreoffice-still-sdk-7.1.7-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_b.js <==
var searchData=
[
  ['landscape_0',['LANDSCAPE',['../namespacecom_1_1sun_1_1star_1_1view.html#a5312aa9f24f5483f2a37fd41a47d852aaad82a3dd15e2be2845cecf9a97017a4a',1,'com::sun::star::view']]],
  ['largetosmall_5fja_5fjp_1',['largeToSmall_ja_JP',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020a600b15e693ae2a5432b4c9ffaa7a756d',1,'com::sun::star::i18n']]],
  ['laser_5ffrom_5fbottom_2',['LASER_FROM_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a8f31d5c35d3aad554f7eb4b351b64972',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fleft_3',['LASER_FROM_LEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a52274ed761d5445556e077b7a6cce373',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5flowerleft_4',['LASER_FROM_LOWERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a3ce4400cb5225c23dc9579ddc5d9fab1',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5flowerright_5',['LASER_FROM_LOWERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a76bbc24c17efd69d773feb8e40ec5b11',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fright_6',['LASER_FROM_RIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a3b9c23ba93291a8d963839d82b715bcb',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5ftop_7',['LASER_FROM_TOP',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a98a99a018fc4a109dbac6aec03be4f14',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fupperleft_8',['LASER_FROM_UPPERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a6b484dcfda331a4b3b0014a38e075556',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fupperright_9',['LASER_FROM_UPPERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a972207ec77cee217c3340a0b91cce5bd',1,'com::sun::star::presentation']]],
  ['lastpage_10',['LASTPAGE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa6e694d634467b88a9cb37eeebc1b07f4',1,'com::sun::star::presentation']]],
  ['layout_11',['LAYOUT',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4af8f713bc0d10a2d2d7b7e61860816992',1,'com::sun::star::drawing']]],
  ['left_12',['LEFT',['../namespacecom_1_1sun_1_1star_1_1table.html#ab3c576b107bd5018643ab5612438fdf2adb45120aafd37a973140edee24708065',1,'com::sun::star::table::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::text::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1style.html#a806c06853615662029f86b19111fe0a2a2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::style::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422a2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::sheet::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::drawing::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1chart.html#a65c2b55fdf73cbbf2fdcfef7d305b6c3adb45120aafd37a973140edee24708065',1,'com::sun::star::chart::LEFT()']]],
  ['left_5fbottom_13',['LEFT_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a8c79964c54afa334cc1053d97ad093d8',1,'com::sun::star::drawing::LEFT_BOTTOM()'],['../namespacecom_1_1sun_1_1star_1_1style.html#ae71ca73feb713866e85597329dfaec2ea8c79964c54afa334cc1053d97ad093d8',1,'com::sun::star::style::LEFT_BOTTOM()']]],
  ['left_5fmiddle_14',['LEFT_MIDDLE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a0d98404411ee5451af67ff3fa419bc56',1,'com::sun::star::drawing::LEFT_MIDDLE()'],['../namespacecom_1_1sun_1_1star_1_1style.html#ae71ca73feb713866e85597329dfaec2ea0d98404411ee5451af67ff3fa419bc56',1,'com::sun::star::style::LEFT_MIDDLE()']]],
  ['left_5fto_5fright_15',['LEFT_TO_RIGHT',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8ba55b57dce74f14a62104ae66e62789eb3',1,'com::sun::star::i18n']]],
  ['left_5fto_5fright_5fembedding_16',['LEFT_TO_RIGHT_EMBEDDING',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8ba1c8b40f41dc560ad35b6589c4a04baac',1,'com::sun::star::i18n']]],
  ['left_5fto_5fright_5foverride_17',['LEFT_TO_RIGHT_OVERRIDE',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8babdd3adc0e8ea29a1e099d7a0d8bd10ed',1,'com::sun::star::i18n']]],
  ['left_5ftop_18',['LEFT_TOP',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a7da02230a1ff90c7f779cbbaf9e91e93',1,'com::sun::star::drawing::LEFT_TOP()'],['../namespacecom_1_1sun_1_1star_1_1style.html#ae71ca73feb713866e85597329dfaec2ea7da02230a1ff90c7f779cbbaf9e91e93',1,'com::sun::star::style::LEFT_TOP()']]],
  ['leftoutside_19',['LEFTOUTSIDE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a38140d53071a431128aa968be9ce4b7da122f6b57646ac923e26dd241ca3af3c6',1,'com::sun::star::drawing']]],
  ['legal_20',['LEGAL',['../namespacecom_1_1sun_1_1star_1_1view.html#a12ab04987d08416f8347a9790c7abf3ea37e165d471cc443933f9be659e7cc803',1,'com::sun::star::view']]],
  ['less_21',['LESS',['../namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1ace23c094d382970cae684969ba8d4880',1,'com::sun::star::sheet']]],
  ['less_5fequal_22',['LESS_EQUAL',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa615fbea5aa163ceb3fdb47472af722c2',1,'com::sun::star::sheet']]],
  ['letter_23',['LETTER',['../namespacecom_1_1sun_1_1star_1_1view.html#a12ab04987d08416f8347a9790c7abf3eab562468170d8ddc207e5ee43d9ee0a2e',1,'com::sun::star::view']]],
  ['line_24',['LINE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a6b5b06de3f4a6ecf7e536a72f2b39c4d',1,'com::sun::star::drawing']]],
  ['line_5fend_25',['LINE_END',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a959c8ebec5e5c8b2418482da8c0752ec',1,'com::sun::star::chart2']]],
  ['line_5fstart_26',['LINE_START',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a7cc652df85c1041c00fde271eb9d8834',1,'com::sun::star::chart2']]],
  ['linear_27',['LINEAR',['../namespacecom_1_1sun_1_1star_1_1awt.html#aa6b9d577a1700f29923f49f7b77d165fadc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::awt::LINEAR()'],['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302badc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::chart::LINEAR()'],['../namespacecom_1_1sun_1_1star_1_1chart2.html#acc7ba74ba6531a134bb92607b8616cb6adc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::chart2::LINEAR()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#a75a9acd74effffae38daed55136b0980adc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::sheet::LINEAR()']]],
  ['lines_28',['LINES',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a6eee32347565343ce84b84adb82da419a0b25cd15c2c168baf13ac0feb3980f40',1,'com::sun::star::chart2::LINES()'],['../namespacecom_1_1sun_1_1star_1_1drawing.html#a086c6f6507c67c8809b218d90998c5d6a0b25cd15c2c168baf13ac0feb3980f40',1,'com::sun::star::drawing::LINES()']]],
  ['link_29',['LINK',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab7b6f3480b7c1c53e953d42a066614b4af2fe1bf26da6f8a451f054e30b3ce0f3',1,'com::sun::star::ucb::LINK()'],['../namespacecom_1_1sun_1_1star_1_1registry.html#a096c2bade01504c38ba808bfeadff2b2af2fe1bf26da6f8a451f054e30b3ce0f3',1,'com::sun::star::registry::LINK()']]],
  ['list_30',['LIST',['../namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aa25688e799536738ea469158ef15fd1c0',1,'com::sun::star::sheet']]],
  ['local_31',['LOCAL',['../namespacecom_1_1sun_1_1star_1_1ucb.html#aea1ce806e915d3505569f7679447ecc2ad0ef00e708ed18ba004480dceb79ecfb',1,'com::sun::star::ucb']]],
  ['lock_32',['LOCK',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a438b68412f24003b09e0993b62dc7b48',1,'com::sun::star::ucb']]],
  ['locking_5fviolation_33',['LOCKING_VIOLATION',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a25f33956ae6388b2de757a973125aa10',1,'com::sun::star::ucb']]],
  ['logarithm_34',['LOGARITHM',['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302ba483c189186b9aac974b7048809587322',1,'com::sun::star::chart']]],
  ['long_35',['LONG',['../namespacecom_1_1sun_1_1star_1_1registry.html#a62fb96939bafde3da828f782a8433ac3aaee055c4a5aba7d55774e4f1c01dacea',1,'com::sun::star::registry::LONG()'],['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328aaee055c4a5aba7d55774e4f1c01dacea',1,'com::sun::star::uno::LONG()']]],
  ['long_5fside_36',['LONG_SIDE',['../namespacecom_1_1sun_1_1star_1_1chart2_1_1data.html#a2afe9ba95ad4b3631057b40391bed0aaab3b0447d5f1a7b0cb85da10a9ce49d26',1,'com::sun::star::chart2::data']]],
  ['longlist_37',['LONGLIST',['../namespacecom_1_1sun_1_1star_1_1registry.html#a62fb96939bafde3da828f782a8433ac3ace2e4184dc388f3ffb9bbfc5c8956574',1,'com::sun::star::registry']]],
  ['low_38',['LOW',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a315655b1bb5848c063491adffde62b15a6a226f4143ca3b18999551694cdb72a8',1,'com::sun::star::ucb']]],
  ['lower_39',['LOWER',['../namespacecom_1_1sun_1_1star_1_1chart.html#a1391f7495aa3a95d4bc29dbf29a809eaaa1017e9b343135a54a98b6f479354d16',1,'com::sun::star::chart']]],
  ['lowercase_5fuppercase_40',['LOWERCASE_UPPERCASE',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020a3819933444f5845a6cd2de2c26bf250c',1,'com::sun::star::i18n']]],
  ['lowest_41',['LOWEST',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a315655b1bb5848c063491adffde62b15ae321c2eb4e64b32d51da602bc6352f1d',1,'com::sun::star::ucb']]],
  ['lr_5ftb_42',['LR_TB',['../namespacecom_1_1sun_1_1star_1_1text.html#a46d11c2d08142ef2d32761c04d1aaa26a89dc073b7a20acdd287619d6e2fe24ca',1,'com::sun::star::text']]],
  ['luminance_43',['LUMINANCE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2ae7d1f96466b5f85058f53320c1525724',1,'com::sun::star::drawing']]]
];

==> libreoffice-still-sdk-7.2.5-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_b.js <==
var searchData=
[
  ['landscape_0',['LANDSCAPE',['../namespacecom_1_1sun_1_1star_1_1view.html#a5312aa9f24f5483f2a37fd41a47d852aaad82a3dd15e2be2845cecf9a97017a4a',1,'com::sun::star::view']]],
  ['largetosmall_5fja_5fjp_1',['largeToSmall_ja_JP',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020a600b15e693ae2a5432b4c9ffaa7a756d',1,'com::sun::star::i18n']]],
  ['laser_5ffrom_5fbottom_2',['LASER_FROM_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a8f31d5c35d3aad554f7eb4b351b64972',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fleft_3',['LASER_FROM_LEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a52274ed761d5445556e077b7a6cce373',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5flowerleft_4',['LASER_FROM_LOWERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a3ce4400cb5225c23dc9579ddc5d9fab1',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5flowerright_5',['LASER_FROM_LOWERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a76bbc24c17efd69d773feb8e40ec5b11',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fright_6',['LASER_FROM_RIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a3b9c23ba93291a8d963839d82b715bcb',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5ftop_7',['LASER_FROM_TOP',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a98a99a018fc4a109dbac6aec03be4f14',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fupperleft_8',['LASER_FROM_UPPERLEFT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a6b484dcfda331a4b3b0014a38e075556',1,'com::sun::star::presentation']]],
  ['laser_5ffrom_5fupperright_9',['LASER_FROM_UPPERRIGHT',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260a972207ec77cee217c3340a0b91cce5bd',1,'com::sun::star::presentation']]],
  ['lastpage_10',['LASTPAGE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa6e694d634467b88a9cb37eeebc1b07f4',1,'com::sun::star::presentation']]],
  ['layout_11',['LAYOUT',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a56943a0946e5f15e5e58054b8e7a04a4af8f713bc0d10a2d2d7b7e61860816992',1,'com::sun::star::drawing']]],
  ['left_12',['LEFT',['../namespacecom_1_1sun_1_1star_1_1table.html#ab3c576b107bd5018643ab5612438fdf2adb45120aafd37a973140edee24708065',1,'com::sun::star::table::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::text::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1style.html#a806c06853615662029f86b19111fe0a2a2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::style::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#af2bbbff47b7abe36f258e59b1351e422a2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::sheet::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1drawing.html#adc845a26c59f91e9ad752a717b3c2386a2349c85ca7362adcde4c67fbd81a4432',1,'com::sun::star::drawing::LEFT()'],['../namespacecom_1_1sun_1_1star_1_1chart.html#a65c2b55fdf73cbbf2fdcfef7d305b6c3adb45120aafd37a973140edee24708065',1,'com::sun::star::chart::LEFT()']]],
  ['left_5fbottom_13',['LEFT_BOTTOM',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a8c79964c54afa334cc1053d97ad093d8',1,'com::sun::star::drawing::LEFT_BOTTOM()'],['../namespacecom_1_1sun_1_1star_1_1style.html#ae71ca73feb713866e85597329dfaec2ea8c79964c54afa334cc1053d97ad093d8',1,'com::sun::star::style::LEFT_BOTTOM()']]],
  ['left_5fmiddle_14',['LEFT_MIDDLE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a0d98404411ee5451af67ff3fa419bc56',1,'com::sun::star::drawing::LEFT_MIDDLE()'],['../namespacecom_1_1sun_1_1star_1_1style.html#ae71ca73feb713866e85597329dfaec2ea0d98404411ee5451af67ff3fa419bc56',1,'com::sun::star::style::LEFT_MIDDLE()']]],
  ['left_5fto_5fright_15',['LEFT_TO_RIGHT',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8ba55b57dce74f14a62104ae66e62789eb3',1,'com::sun::star::i18n']]],
  ['left_5fto_5fright_5fembedding_16',['LEFT_TO_RIGHT_EMBEDDING',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8ba1c8b40f41dc560ad35b6589c4a04baac',1,'com::sun::star::i18n']]],
  ['left_5fto_5fright_5foverride_17',['LEFT_TO_RIGHT_OVERRIDE',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8babdd3adc0e8ea29a1e099d7a0d8bd10ed',1,'com::sun::star::i18n']]],
  ['left_5ftop_18',['LEFT_TOP',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a4689f50c3960db0e79b179ddfc7d8827a7da02230a1ff90c7f779cbbaf9e91e93',1,'com::sun::star::drawing::LEFT_TOP()'],['../namespacecom_1_1sun_1_1star_1_1style.html#ae71ca73feb713866e85597329dfaec2ea7da02230a1ff90c7f779cbbaf9e91e93',1,'com::sun::star::style::LEFT_TOP()']]],
  ['leftoutside_19',['LEFTOUTSIDE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a38140d53071a431128aa968be9ce4b7da122f6b57646ac923e26dd241ca3af3c6',1,'com::sun::star::drawing']]],
  ['legal_20',['LEGAL',['../namespacecom_1_1sun_1_1star_1_1view.html#a12ab04987d08416f8347a9790c7abf3ea37e165d471cc443933f9be659e7cc803',1,'com::sun::star::view']]],
  ['less_21',['LESS',['../namespacecom_1_1sun_1_1star_1_1sheet.html#af9e5fd8fd26fc252748d97ebd68ea6b1ace23c094d382970cae684969ba8d4880',1,'com::sun::star::sheet']]],
  ['less_5fequal_22',['LESS_EQUAL',['../namespacecom_1_1sun_1_1star_1_1sheet.html#a491ab8ed5b7b5809e7be869d26b071cfa615fbea5aa163ceb3fdb47472af722c2',1,'com::sun::star::sheet']]],
  ['letter_23',['LETTER',['../namespacecom_1_1sun_1_1star_1_1view.html#a12ab04987d08416f8347a9790c7abf3eab562468170d8ddc207e5ee43d9ee0a2e',1,'com::sun::star::view']]],
  ['line_24',['LINE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a6b5b06de3f4a6ecf7e536a72f2b39c4d',1,'com::sun::star::drawing']]],
  ['line_5fend_25',['LINE_END',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a959c8ebec5e5c8b2418482da8c0752ec',1,'com::sun::star::chart2']]],
  ['line_5fstart_26',['LINE_START',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a7cc652df85c1041c00fde271eb9d8834',1,'com::sun::star::chart2']]],
  ['linear_27',['LINEAR',['../namespacecom_1_1sun_1_1star_1_1awt.html#aa6b9d577a1700f29923f49f7b77d165fadc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::awt::LINEAR()'],['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302badc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::chart::LINEAR()'],['../namespacecom_1_1sun_1_1star_1_1chart2.html#acc7ba74ba6531a134bb92607b8616cb6adc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::chart2::LINEAR()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#a75a9acd74effffae38daed55136b0980adc101ebf31c49c2d4b80b7c6f59f22cb',1,'com::sun::star::sheet::LINEAR()']]],
  ['lines_28',['LINES',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a6eee32347565343ce84b84adb82da419a0b25cd15c2c168baf13ac0feb3980f40',1,'com::sun::star::chart2::LINES()'],['../namespacecom_1_1sun_1_1star_1_1drawing.html#a086c6f6507c67c8809b218d90998c5d6a0b25cd15c2c168baf13ac0feb3980f40',1,'com::sun::star::drawing::LINES()']]],
  ['link_29',['LINK',['../namespacecom_1_1sun_1_1star_1_1registry.html#a096c2bade01504c38ba808bfeadff2b2af2fe1bf26da6f8a451f054e30b3ce0f3',1,'com::sun::star::registry::LINK()'],['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab7b6f3480b7c1c53e953d42a066614b4af2fe1bf26da6f8a451f054e30b3ce0f3',1,'com::sun::star::ucb::LINK()']]],
  ['list_30',['LIST',['../namespacecom_1_1sun_1_1star_1_1sheet.html#aa5aa6dbecaeb5e18a476b0a58279c57aa25688e799536738ea469158ef15fd1c0',1,'com::sun::star::sheet']]],
  ['local_31',['LOCAL',['../namespacecom_1_1sun_1_1star_1_1ucb.html#aea1ce806e915d3505569f7679447ecc2ad0ef00e708ed18ba004480dceb79ecfb',1,'com::sun::star::ucb']]],
  ['lock_32',['LOCK',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a438b68412f24003b09e0993b62dc7b48',1,'com::sun::star::ucb']]],
  ['locking_5fviolation_33',['LOCKING_VIOLATION',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a25f33956ae6388b2de757a973125aa10',1,'com::sun::star::ucb']]],
  ['logarithm_34',['LOGARITHM',['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302ba483c189186b9aac974b7048809587322',1,'com::sun::star::chart']]],
  ['long_35',['LONG',['../namespacecom_1_1sun_1_1star_1_1registry.html#a62fb96939bafde3da828f782a8433ac3aaee055c4a5aba7d55774e4f1c01dacea',1,'com::sun::star::registry::LONG()'],['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328aaee055c4a5aba7d55774e4f1c01dacea',1,'com::sun::star::uno::LONG()']]],
  ['long_5fside_36',['LONG_SIDE',['../namespacecom_1_1sun_1_1star_1_1chart2_1_1data.html#a2afe9ba95ad4b3631057b40391bed0aaab3b0447d5f1a7b0cb85da10a9ce49d26',1,'com::sun::star::chart2::data']]],
  ['longlist_37',['LONGLIST',['../namespacecom_1_1sun_1_1star_1_1registry.html#a62fb96939bafde3da828f782a8433ac3ace2e4184dc388f3ffb9bbfc5c8956574',1,'com::sun::star::registry']]],
  ['low_38',['LOW',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a315655b1bb5848c063491adffde62b15a6a226f4143ca3b18999551694cdb72a8',1,'com::sun::star::ucb']]],
  ['lower_39',['LOWER',['../namespacecom_1_1sun_1_1star_1_1chart.html#a1391f7495aa3a95d4bc29dbf29a809eaaa1017e9b343135a54a98b6f479354d16',1,'com::sun::star::chart']]],
  ['lowercase_5fuppercase_40',['LOWERCASE_UPPERCASE',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a436afb2c972c4d40d888b71482e93020a3819933444f5845a6cd2de2c26bf250c',1,'com::sun::star::i18n']]],
  ['lowest_41',['LOWEST',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a315655b1bb5848c063491adffde62b15ae321c2eb4e64b32d51da602bc6352f1d',1,'com::sun::star::ucb']]],
  ['lr_5ftb_42',['LR_TB',['../namespacecom_1_1sun_1_1star_1_1text.html#a46d11c2d08142ef2d32761c04d1aaa26a89dc073b7a20acdd287619d6e2fe24ca',1,'com::sun::star::text']]],
  ['luminance_43',['LUMINANCE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adaf903dffc9b5178ac0a76faef6142f2ae7d1f96466b5f85058f53320c1525724',1,'com::sun::star::drawing']]]
];
